==> zio-aws-networkmanager_2.13-5.17.121.3-sources.jar: zio/aws/networkmanager/model/RestoreCoreNetworkPolicyVersionRequest.scala <==
package zio.aws.networkmanager.model
import zio.ZIO
import zio.aws.networkmanager.model.primitives.{Integer, CoreNetworkId}
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class RestoreCoreNetworkPolicyVersionRequest(
    coreNetworkId: CoreNetworkId,
    policyVersionId: Integer
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.networkmanager.model.RestoreCoreNetworkPolicyVersionRequest = {
    import RestoreCoreNetworkPolicyVersionRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.networkmanager.model.RestoreCoreNetworkPolicyVersionRequest
      .builder()
      .coreNetworkId(CoreNetworkId.unwrap(coreNetworkId): java.lang.String)
      .policyVersionId(Integer.unwrap(policyVersionId): java.lang.Integer)
      .build()
  }
  def asReadOnly
      : zio.aws.networkmanager.model.RestoreCoreNetworkPolicyVersionRequest.ReadOnly =
    zio.aws.networkmanager.model.RestoreCoreNetworkPolicyVersionRequest
      .wrap(buildAwsValue())
}
object RestoreCoreNetworkPolicyVersionRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.networkmanager.model.RestoreCoreNetworkPolicyVersionRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.networkmanager.model.RestoreCoreNetworkPolicyVersionRequest =
      zio.aws.networkmanager.model
        .RestoreCoreNetworkPolicyVersionRequest(coreNetworkId, policyVersionId)
    def coreNetworkId: CoreNetworkId
    def policyVersionId: Integer
    def getCoreNetworkId: ZIO[Any, Nothing, CoreNetworkId] =
      ZIO.succeed(coreNetworkId)
    def getPolicyVersionId: ZIO[Any, Nothing, Integer] =
      ZIO.succeed(policyVersionId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.networkmanager.model.RestoreCoreNetworkPolicyVersionRequest
  ) extends zio.aws.networkmanager.model.RestoreCoreNetworkPolicyVersionRequest.ReadOnly {
    override val coreNetworkId: CoreNetworkId =
      zio.aws.networkmanager.model.primitives
        .CoreNetworkId(impl.coreNetworkId())
    override val policyVersionId: Integer =
      zio.aws.networkmanager.model.primitives.Integer(impl.policyVersionId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.networkmanager.model.RestoreCoreNetworkPolicyVersionRequest
  ): zio.aws.networkmanager.model.RestoreCoreNetworkPolicyVersionRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-networkmanager_2.13-5.17.295.1-sources.jar: zio/aws/networkmanager/model/RestoreCoreNetworkPolicyVersionRequest.scala <==
package zio.aws.networkmanager.model
import zio.ZIO
import zio.aws.networkmanager.model.primitives.{Integer, CoreNetworkId}
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class RestoreCoreNetworkPolicyVersionRequest(
    coreNetworkId: CoreNetworkId,
    policyVersionId: Integer
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.networkmanager.model.RestoreCoreNetworkPolicyVersionRequest = {
    import RestoreCoreNetworkPolicyVersionRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.networkmanager.model.RestoreCoreNetworkPolicyVersionRequest
      .builder()
      .coreNetworkId(CoreNetworkId.unwrap(coreNetworkId): java.lang.String)
      .policyVersionId(policyVersionId: java.lang.Integer)
      .build()
  }
  def asReadOnly
      : zio.aws.networkmanager.model.RestoreCoreNetworkPolicyVersionRequest.ReadOnly =
    zio.aws.networkmanager.model.RestoreCoreNetworkPolicyVersionRequest
      .wrap(buildAwsValue())
}
object RestoreCoreNetworkPolicyVersionRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.networkmanager.model.RestoreCoreNetworkPolicyVersionRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.networkmanager.model.RestoreCoreNetworkPolicyVersionRequest =
      zio.aws.networkmanager.model
        .RestoreCoreNetworkPolicyVersionRequest(coreNetworkId, policyVersionId)
    def coreNetworkId: CoreNetworkId
    def policyVersionId: Integer
    def getCoreNetworkId: ZIO[Any, Nothing, CoreNetworkId] =
      ZIO.succeed(coreNetworkId)
    def getPolicyVersionId: ZIO[Any, Nothing, Integer] =
      ZIO.succeed(policyVersionId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.networkmanager.model.RestoreCoreNetworkPolicyVersionRequest
  ) extends zio.aws.networkmanager.model.RestoreCoreNetworkPolicyVersionRequest.ReadOnly {
    override val coreNetworkId: CoreNetworkId =
      zio.aws.networkmanager.model.primitives
        .CoreNetworkId(impl.coreNetworkId())
    override val policyVersionId: Integer = impl.policyVersionId(): Integer
  }
  def wrap(
      impl: software.amazon.awssdk.services.networkmanager.model.RestoreCoreNetworkPolicyVersionRequest
  ): zio.aws.networkmanager.model.RestoreCoreNetworkPolicyVersionRequest.ReadOnly =
    new Wrapper(impl)
}
